Learn R Programming

lmem.gwaser (version 0.1.0)

QA_sim: Name of the file containing phenotypic information

Description

A research program (MABDE) was set up to investigate patterns of adaptation in barley. In this project a large set of barley genotypes (~190 genotypes) were evaluated in Europe and in the Mediterranean region. More details about this population and research can be found in Comadran et al. (2009). In this example we simulate the phenotipic data in three environments, for a set of 179 genotypes. The population was genotyped by DArTs.

Usage

QA_sim

Arguments

Format

A data frame 179 genotypes and 3 variables.

MABDE